#!/usr/bin/env python
# encoding: utf-8
"""
pygeodb/__init__.py

Created by Maximillian Dornseif on 2010-01-16.
Copyright (c) 2010 HUDORA. All rights reserved.
"""

from __future__ import absolute_import
from __future__ import division

from pygeodb.pygeodb_core import *
